@@ -1,3 +1,7 @@
+<?php
+$acl = new ACL();
+if ($acl->hasPermission("umanage_client")) {
+    ?>
 <h1><?php translate("add_site");?></h1>
 <form action="index.php?action=module_settings&module=umanage_client"
 	method="post">
@@ -14,4 +18,10 @@
 		type="text" name="api_key" value="" maxlength="255" required> <br /> <br />
 	<input type="submit" value="<?php translate("save");?>"> <input
 		type="hidden" name="form_action" value="create_site">
-</form>
\ No newline at end of file
+</form>
+
+<?php
+} else {
+    noperms();
+}
+?>
\ No newline at end of file
